# Falcon Eye
### Suite of tools for Data Exploration

#### TOOLS IN DEVELOPLMENT

## Dictionary/List Walk
```python
from FalconEye import Walk
Walk(object).items #returns all found values
```
## Walk(object)
Parameters
- object - List/Dict like object for reading